@@ -196,6 +196,8 @@ def dB_to_dBA(values, freqs):
         )
     )
     Aweight = 2.0 + 20.0 * log10(RA)
+    Aweight[RA==0] = -100 # replacing -Inf by -100 dB
+    Aweight[values<=0] = 0 # avoiding to increase dB in dBA at frequencies where noise is already null
     try:
         values += Aweight
         return values
