@@ -23,7 +23,7 @@ def extract_slices(self, values, axes_list):
         for axis_requested in axes_list:
             if axis.name == axis_requested.corr_name:
                 is_match = True
-                if axis_requested.indices is not None:
+                if axis_requested.indices is not None and axis_requested.transform != "fft":
                     values = take(values, axis_requested.indices, axis=index)
         if not is_match:  # Axis was not specified -> take slice at the first value
             values = take(values, [0], axis=index)
